@@ -4,6 +4,11 @@ import os
 import numpy
 import h5py
 
+import scipy.constants as codata
+import xraylib
+
+from srxraylib.util.h5_simple_writer import H5SimpleWriter
+
 from PyQt5.QtWidgets import QApplication, QMessageBox, QSizePolicy
 from PyQt5.QtGui import QIntValidator, QDoubleValidator
 
@@ -12,15 +17,18 @@ from orangewidget.settings import Setting
 
 from oasys.widgets import gui as oasysgui, congruence
 from oasys.widgets.exchange import DataExchangeObject
-
-from oasys.util.oasys_util import TTYGrabber
-from orangecontrib.xoppy.widgets.gui.ow_xoppy_widget import XoppyWidget
-from orangecontrib.xoppy.util.xoppy_xraylib_util import reflectivity_fresnel
 from oasys.widgets.gui import ConfirmDialog
 
-import scipy.constants as codata
-import xraylib
-from srxraylib.util.h5_simple_writer import H5SimpleWriter
+from oasys.util.oasys_util import TTYGrabber
+
+from orangecontrib.xoppy.widgets.gui.ow_xoppy_widget import XoppyWidget
+from orangecontrib.xoppy.util.xoppy_xraylib_util import reflectivity_fresnel
+from orangecontrib.xoppy.util.xoppy_xraylib_util import nist_compound_list, density
+
+
+
+
+
 
 class OWpower3Dcomponent(XoppyWidget):
     name = "Power3Dcomponent"
@@ -534,60 +542,6 @@ class OWpower3Dcomponent(XoppyWidget):
             except:
                 pass
 
-    # TODO: integrate this in ow_xoppy_widget
-    def plot_data3D(self, data3D, dataE, dataX, dataY, tabs_canvas_index, plot_canvas_index,
-                    title="", xtitle="", ytitle="", color_limits_uniform=False):
-
-        from silx.gui.plot.StackView import StackViewMainWindow # TODO (re)move
-
-        for i in range(1+self.tab[tabs_canvas_index].layout().count()):
-            self.tab[tabs_canvas_index].layout().removeItem(self.tab[tabs_canvas_index].layout().itemAt(i))
-
-        #self.tab[tabs_canvas_index].layout().removeItem(self.tab[tabs_canvas_index].layout().itemAt(0))
-
-
-        xmin = numpy.min(dataX)
-        xmax = numpy.max(dataX)
-        ymin = numpy.min(dataY)
-        ymax = numpy.max(dataY)
-
-
-        stepX = dataX[1]-dataX[0]
-        stepY = dataY[1]-dataY[0]
-        if len(dataE) > 1: stepE = dataE[1]-dataE[0]
-        else: stepE = 1.0
-
-        if stepE == 0.0: stepE = 1.0
-        if stepX == 0.0: stepX = 1.0
-        if stepY == 0.0: stepY = 1.0
-
-        dim0_calib = (dataE[0],stepE)
-        dim1_calib = (ymin, stepY)
-        dim2_calib = (xmin, stepX)
-
-
-        data_to_plot = numpy.swapaxes(data3D,1,2)
-
-        if color_limits_uniform:
-            colormap = {"name":"temperature", "normalization":"linear", "autoscale":False, "vmin":data3D.min(), "vmax":data3D.max(), "colors":256}
-
-        else:
-            colormap = {"name":"temperature", "normalization":"linear", "autoscale":True, "vmin":0, "vmax":0, "colors":256}
-
-        self.plot_canvas[plot_canvas_index] = StackViewMainWindow()
-
-        self.plot_canvas[plot_canvas_index].setGraphTitle(title)
-        self.plot_canvas[plot_canvas_index].setLabels(["Photon Energy [eV]",ytitle,xtitle])
-        self.plot_canvas[plot_canvas_index].setColormap(colormap=colormap)
-        self.plot_canvas[plot_canvas_index].setTitleCallback(lambda idx: "Energy: %6.3f eV"%dataE[idx])
-
-        self.plot_canvas[plot_canvas_index].setStack(numpy.array(data_to_plot),
-                                                     calibrations=[dim0_calib, dim1_calib, dim2_calib] )
-        self.tab[tabs_canvas_index].layout().addWidget(self.plot_canvas[plot_canvas_index])
-
-
-
-
     def xoppy_calc_power3Dcomponent(self):
 
         #
@@ -634,12 +588,12 @@ class OWpower3Dcomponent(XoppyWidget):
             try:  # apply written value
                 rho = float(dens)
             except:   # in case of ?
-                grabber = TTYGrabber()
-                grabber.start()
-                rho = xraylib.ElementDensity(xraylib.SymbolToAtomicNumber(substance))
-                grabber.stop()
-                for row in grabber.ttyData:
-                    self.writeStdOut(row)
+                # grabber = TTYGrabber()
+                # grabber.start()
+                rho = density(substance)
+                # grabber.stop()
+                # for row in grabber.ttyData:
+                #     self.writeStdOut(row)
                 print("Density for %s: %g g/cm3"%(substance,rho))
             dens = rho
 
@@ -997,32 +951,29 @@ def integral_3d(data3D, e=None, h=None, v=None, method=0):
 
 if __name__ == "__main__":
 
-    # # create unulator_radiation xoppy exchange data
-    # from orangecontrib.xoppy.util.xoppy_undulators import xoppy_calc_undulator_radiation
-    # from oasys.widgets.exchange import DataExchangeObject
-    #
-    # e, h, v, p, code = xoppy_calc_undulator_radiation(ELECTRONENERGY=6.04,ELECTRONENERGYSPREAD=0.001,ELECTRONCURRENT=0.2,\
-    #                                    ELECTRONBEAMSIZEH=0.000395,ELECTRONBEAMSIZEV=9.9e-06,\
-    #                                    ELECTRONBEAMDIVERGENCEH=1.05e-05,ELECTRONBEAMDIVERGENCEV=3.9e-06,\
-    #                                    PERIODID=0.018,NPERIODS=222,KV=1.68,DISTANCE=30.0,
-    #                                    SETRESONANCE=0,HARMONICNUMBER=1,
-    #                                    GAPH=0.001,GAPV=0.001,\
-    #                                    HSLITPOINTS=41,VSLITPOINTS=41,METHOD=2,
-    #                                    PHOTONENERGYMIN=7000,PHOTONENERGYMAX=8100,PHOTONENERGYPOINTS=20,
-    #                                    USEEMITTANCES=1)
-    #
-    # received_data = DataExchangeObject("XOPPY", "Power3Dcomponent")
-    # received_data.add_content("xoppy_data", [p, e, h, v])
-    # received_data.add_content("xoppy_code", code)
+    # create unulator_radiation xoppy exchange data
+    from orangecontrib.xoppy.util.xoppy_undulators import xoppy_calc_undulator_radiation
+    from oasys.widgets.exchange import DataExchangeObject
+
+    e, h, v, p, code = xoppy_calc_undulator_radiation(ELECTRONENERGY=6.04,ELECTRONENERGYSPREAD=0.001,ELECTRONCURRENT=0.2,\
+                                       ELECTRONBEAMSIZEH=0.000395,ELECTRONBEAMSIZEV=9.9e-06,\
+                                       ELECTRONBEAMDIVERGENCEH=1.05e-05,ELECTRONBEAMDIVERGENCEV=3.9e-06,\
+                                       PERIODID=0.018,NPERIODS=222,KV=1.68,DISTANCE=30.0,
+                                       SETRESONANCE=0,HARMONICNUMBER=1,
+                                       GAPH=0.001,GAPV=0.001,\
+                                       HSLITPOINTS=41,VSLITPOINTS=41,METHOD=2,
+                                       PHOTONENERGYMIN=7000,PHOTONENERGYMAX=8100,PHOTONENERGYPOINTS=20,
+                                       USEEMITTANCES=1)
+
+    received_data = DataExchangeObject("XOPPY", "Power3Dcomponent")
+    received_data.add_content("xoppy_data", [p, e, h, v])
+    received_data.add_content("xoppy_code", code)
 
 
     #
     app = QApplication(sys.argv)
     w = OWpower3Dcomponent()
-
-    # w.acceptExchangeData(received_data)
-
+    w.acceptExchangeData(received_data)
     w.show()
     app.exec()
-
     w.saveSettings()
